aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJakob Unterwurzacher2021-03-27 15:30:01 +0100
committerJakob Unterwurzacher2021-03-27 15:30:01 +0100
commite0981ea59ba9224ddbd96a376fccea758e3e0d7c (patch)
tree4e437d1710bc71c4b0fbbced0eb20282264f7a22
parentdb91050f9e492595c82a551f70b3069a952912fe (diff)
package-static.bash: add gocryptfs-xray to tarball
Requested here https://github.com/rfjakob/gocryptfs/issues/558 and here https://github.com/rfjakob/gocryptfs/issues/496 Closes https://github.com/rfjakob/gocryptfs/issues/496
-rwxr-xr-xpackage-static.bash14
1 files changed, 9 insertions, 5 deletions
diff --git a/package-static.bash b/package-static.bash
index 4cc5063..ce8cecb 100755
--- a/package-static.bash
+++ b/package-static.bash
@@ -6,20 +6,24 @@ cd "$(dirname "$0")"
source build-without-openssl.bash
if ldd gocryptfs > /dev/null ; then
- echo "error: compiled binary is not static"
+ echo "error: compiled gocryptfs binary is not static"
exit 1
fi
# Build gocryptfs.1 man page
./Documentation/MANPAGE-render.bash > /dev/null
-cp -a ./Documentation/gocryptfs.1 .
ARCH=$(go env GOARCH)
OS=$(go env GOOS)
-TARGZ=gocryptfs_${GITVERSION}_${OS}-static_${ARCH}.tar.gz
+TARBALL=gocryptfs_${GITVERSION}_${OS}-static_${ARCH}.tar
+TARGZ=$TARBALL.gz
-tar --owner=root --group=root -czf "$TARGZ" gocryptfs gocryptfs.1
+tar --owner=root --group=root --create -vf "$TARBALL" gocryptfs
+tar --owner=root --group=root --append -vf "$TARBALL" -C gocryptfs-xray gocryptfs-xray
+tar --owner=root --group=root --append -vf "$TARBALL" -C Documentation gocryptfs.1 gocryptfs-xray.1
+
+gzip -f "$TARBALL"
echo "Tar created."
echo "Hint for signing: gpg -u 23A02740 --armor --detach-sig $TARGZ"
@@ -6,20 +6,24 @@ cd "$(dirname "$0")"
exit 1
fi
-# Build gocryptfs.1 man page
+# Build man pages gocryptfs.1 & gocryptfs-xray.1
./Documentation/MANPAGE-render.bash > /dev/null